/// <reference types="jest" />
/**
 * jest Mock for nested functions
 */
export type NestingMock = jest.Mock & {
    /**
     * List of consecutive call arguments to this nested mock
     * @readonly
     */
    readonly callPath: ReadonlyArray<ReadonlyArray<any>>;
};
/**
 * Creates a jest mock for a nested function
 * @param {number} [depth=2] depth of nesting
 * @param {(...args: any[]) => any} [tailImplementation] Implementation for the deepest nested function
 * @returns {NestingMock} the mock
 */
export declare const fnNested: (depth?: number, tailImplementation?: ((this: NestingMock, ...args: any[]) => any) | undefined) => NestingMock;
