"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fnNested = void 0;
const fnNestedInternal = (depth, tailImplementation, callPath = []) => {
    if (depth < 1 || depth % 1 !== 0)
        throw new Error('Depth must be a whole number greater than 0.');
    if (depth === 1) {
        const tail = jest.fn();
        Object.defineProperty(tail, 'callPath', { get: () => callPath });
        tail.mockImplementation(tailImplementation === null || tailImplementation === void 0 ? void 0 : tailImplementation.bind(tail));
        return tail;
    }
    const root = jest.fn((...args) => fnNestedInternal(depth - 1, tailImplementation, [...callPath, args]));
    Object.defineProperty(root, 'callPath', { get: () => callPath });
    return root;
};
/**
 * Creates a jest mock for a nested function
 * @param {number} [depth=2] depth of nesting
 * @param {(...args: any[]) => any} [tailImplementation] Implementation for the deepest nested function
 * @returns {NestingMock} the mock
 */
const fnNested = (depth = 2, tailImplementation) => fnNestedInternal(depth, tailImplementation);
exports.fnNested = fnNested;
//# sourceMappingURL=nestingMock.js.map